@@ -5,18 +5,14 @@ perl.pl - runs Perl language interpreter under Perl virtual environment
 
 =head1 VERSION
 
-version 1.11
+version 1.12
 
 =head1 SYNOPSIS
 
 runs Perl language interpreter under Perl virtual environment
 
-=over
-
 [I<environment_path>/bin/]B<perl.pl> [I<argument>]...
 
-=back
-
 =cut
 use strict;
 use warnings;
@@ -28,16 +24,22 @@ use open qw(:std :locale);
 use App::Virtualenv;
 
 
-App::Virtualenv::activate;
+App::Virtualenv::activate();
 exit App::Virtualenv::perl(@ARGV);
 __END__
+=head1 REPOSITORY
+
+B<GitHub> L<https://github.com/orkunkaraduman/perl5-virtualenv>
+
+B<CPAN> L<https://metacpan.org/release/App-Virtualenv>
+
 =head1 AUTHOR
 
 Orkun Karaduman <orkunkaraduman@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2016  Orkun Karaduman <orkunkaraduman@gmail.com>
+Copyright (C) 2017  Orkun Karaduman <orkunkaraduman@gmail.com>
 
 This program is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
